@@ -18,6 +18,10 @@
  * along with this library; if not, see <http://www.gnu.org/licenses/>.
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "gtksourcebufferinternal.h"
 #include "gtksourcebuffer.h"
 #include "gtksourcesearchcontext.h"
