@@ -15,9 +15,8 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this library; if not, see <http://www.gnu.org/licenses/>.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -768,6 +767,7 @@ end_append_text_to_document (GtkSourceBufferOutputStream *stream)
 	gtk_text_buffer_set_modified (GTK_TEXT_BUFFER (stream->priv->source_buffer),
 	                              FALSE);
 
+	gtk_text_buffer_end_user_action (GTK_TEXT_BUFFER (stream->priv->source_buffer));
 	gtk_source_buffer_end_not_undoable_action (stream->priv->source_buffer);
 }
 
@@ -926,13 +926,13 @@ gtk_source_buffer_output_stream_write (GOutputStream  *stream,
 				if (errno == EINVAL)
 				{
 					g_set_error (error, G_IO_ERROR, G_IO_ERROR_NOT_SUPPORTED,
-						     _("Conversion from character set '%s' to 'UTF-8' is not supported"),
+						     _("Conversion from character set “%s” to “UTF-8” is not supported"),
 						     from_charset);
 				}
 				else
 				{
 					g_set_error (error, G_IO_ERROR, G_IO_ERROR_FAILED,
-						     _("Could not open converter from '%s' to 'UTF-8'"),
+						     _("Could not open converter from “%s” to “UTF-8”"),
 						     from_charset);
 				}
 
@@ -945,8 +945,13 @@ gtk_source_buffer_output_stream_write (GOutputStream  *stream,
 			g_free (from_charset);
 		}
 
-		/* Init the undoable action */
+		/* Begin not undoable action. Begin also a normal user action,
+		 * since we load the file chunk by chunk and it should be seen
+		 * as only one action, for the features that rely on the user
+		 * action.
+		 */
 		gtk_source_buffer_begin_not_undoable_action (ostream->priv->source_buffer);
+		gtk_text_buffer_begin_user_action (GTK_TEXT_BUFFER (ostream->priv->source_buffer));
 
 		gtk_text_buffer_get_start_iter (GTK_TEXT_BUFFER (ostream->priv->source_buffer),
 		                                &ostream->priv->pos);
