@@ -14,21 +14,18 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this library; if not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef __GTK_SOURCE_COMPLETION_PIVATE_H__
-#define __GTK_SOURCE_COMPLETION_PIVATE_H__
+#ifndef GTK_SOURCE_COMPLETION_PIVATE_H
+#define GTK_SOURCE_COMPLETION_PIVATE_H
 
 #include <gtk/gtk.h>
 #include <gtksourceview/gtksourcetypes.h>
 
-/* Forward declaration */
-struct _GtkSourceView;
+G_GNUC_INTERNAL
+GtkSourceCompletion *gtk_source_completion_new (GtkSourceView *source_view);
 
-GtkSourceCompletion *gtk_source_completion_new (struct _GtkSourceView *source_view);
-
-#endif /* __GTK_SOURCE_COMPLETION_PIVATE_H__ */
+#endif /* GTK_SOURCE_COMPLETION_PIVATE_H */
 
