@@ -14,13 +14,12 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this library; if not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef __GTK_SOURCE_COMPLETION_CONTAINER_H__
-#define __GTK_SOURCE_COMPLETION_CONTAINER_H__
+#ifndef GTK_SOURCE_COMPLETION_CONTAINER_H
+#define GTK_SOURCE_COMPLETION_CONTAINER_H
 
 #include <gtk/gtk.h>
 #include "gtksourcetypes-private.h"
@@ -55,4 +54,4 @@ GtkSourceCompletionContainer *
 
 G_END_DECLS
 
-#endif /* __GTK_SOURCE_COMPLETION_CONTAINER_H__ */
+#endif /* GTK_SOURCE_COMPLETION_CONTAINER_H */
