@@ -463,6 +463,14 @@ gtk_source_file_saver_class_init (GtkSourceFileSaverClass *klass)
 							     G_PARAM_READWRITE |
 							     G_PARAM_CONSTRUCT |
 							     G_PARAM_STATIC_STRINGS));
+
+	/* Due to potential deadlocks when registering types, we need to
+	 * ensure the dependent private class GtkSourceBufferInputStream
+	 * has been registered up front.
+	 *
+	 * See https://bugzilla.gnome.org/show_bug.cgi?id=780216
+	 */
+	g_type_ensure (GTK_SOURCE_TYPE_BUFFER_INPUT_STREAM);
 }
 
 static void
