@@ -14,13 +14,12 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this library; if not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef __GTK_SOURCE_GUTTER_RENDERER_MARKS_H__
-#define __GTK_SOURCE_GUTTER_RENDERER_MARKS_H__
+#ifndef GTK_SOURCE_GUTTER_RENDERER_MARKS_H
+#define GTK_SOURCE_GUTTER_RENDERER_MARKS_H
 
 #include <gtk/gtk.h>
 #include "gtksourcetypes.h"
@@ -57,4 +56,4 @@ GtkSourceGutterRenderer *gtk_source_gutter_renderer_marks_new (void);
 
 G_END_DECLS
 
-#endif /* __GTK_SOURCE_GUTTER_RENDERER_MARKS_H__ */
+#endif /* GTK_SOURCE_GUTTER_RENDERER_MARKS_H */
