@@ -14,9 +14,8 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this library; if not, see <http://www.gnu.org/licenses/>.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -82,20 +81,17 @@ gutter_renderer_text_begin (GtkSourceGutterRenderer *renderer,
 }
 
 static void
-center_on (GtkSourceGutterRenderer *renderer,
-           GdkRectangle            *cell_area,
-           GtkTextIter             *iter,
-           gint                     width,
-           gint                     height,
-           gfloat                   xalign,
-           gfloat                   yalign,
-           gint                    *x,
-           gint                    *y)
+center_on (GtkTextView  *view,
+           GdkRectangle *cell_area,
+           GtkTextIter  *iter,
+           gint          width,
+           gint          height,
+           gfloat        xalign,
+           gfloat        yalign,
+           gint         *x,
+           gint         *y)
 {
 	GdkRectangle location;
-	GtkTextView *view;
-
-	view = gtk_source_gutter_renderer_get_view (renderer);
 
 	gtk_text_view_get_iter_location (view, iter, &location);
 
@@ -113,6 +109,7 @@ gutter_renderer_text_draw (GtkSourceGutterRenderer      *renderer,
 			   GtkSourceGutterRendererState  state)
 {
 	GtkSourceGutterRendererText *text = GTK_SOURCE_GUTTER_RENDERER_TEXT (renderer);
+	GtkTextView *view;
 	gint width;
 	gint height;
 	gfloat xalign;
@@ -120,7 +117,6 @@ gutter_renderer_text_draw (GtkSourceGutterRenderer      *renderer,
 	GtkSourceGutterRendererAlignmentMode mode;
 	gint x = 0;
 	gint y = 0;
-	GtkTextView *view;
 	GtkStyleContext *context;
 
 	/* Chain up to draw background */
@@ -135,6 +131,8 @@ gutter_renderer_text_draw (GtkSourceGutterRenderer      *renderer,
 												       state);
 	}
 
+	view = gtk_source_gutter_renderer_get_view (renderer);
+
 	if (text->priv->is_markup)
 	{
 		pango_layout_set_markup (text->priv->cached_layout,
@@ -154,7 +152,15 @@ gutter_renderer_text_draw (GtkSourceGutterRenderer      *renderer,
 	                                          &xalign,
 	                                          &yalign);
 
-	mode = gtk_source_gutter_renderer_get_alignment_mode (renderer);
+	/* Avoid calculations if we don't wrap text */
+	if (gtk_text_view_get_wrap_mode (view) == GTK_WRAP_NONE)
+	{
+		mode = GTK_SOURCE_GUTTER_RENDERER_ALIGNMENT_MODE_CELL;
+	}
+	else
+	{
+		mode = gtk_source_gutter_renderer_get_alignment_mode (renderer);
+	}
 
 	switch (mode)
 	{
@@ -164,7 +170,7 @@ gutter_renderer_text_draw (GtkSourceGutterRenderer      *renderer,
 			break;
 
 		case GTK_SOURCE_GUTTER_RENDERER_ALIGNMENT_MODE_FIRST:
-			center_on (renderer,
+			center_on (view,
 			           cell_area,
 			           start,
 			           width,
@@ -176,7 +182,7 @@ gutter_renderer_text_draw (GtkSourceGutterRenderer      *renderer,
 			break;
 
 		case GTK_SOURCE_GUTTER_RENDERER_ALIGNMENT_MODE_LAST:
-			center_on (renderer,
+			center_on (view,
 			           cell_area,
 			           end,
 			           width,
@@ -191,7 +197,6 @@ gutter_renderer_text_draw (GtkSourceGutterRenderer      *renderer,
 			g_assert_not_reached ();
 	}
 
-	view = gtk_source_gutter_renderer_get_view (renderer);
 	context = gtk_widget_get_style_context (GTK_WIDGET (view));
 	gtk_render_layout (context, cr, x, y, text->priv->cached_layout);
 }
