@@ -14,9 +14,8 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this library; if not, see <http://www.gnu.org/licenses/>.
  */
 
 #ifndef GTK_SOURCE_ITER_H
@@ -56,6 +55,14 @@ GTK_SOURCE_INTERNAL
 gboolean	_gtk_source_iter_ends_extra_natural_word		(const GtkTextIter *iter,
 									 gboolean           visible);
 
+GTK_SOURCE_INTERNAL
+void		_gtk_source_iter_get_leading_spaces_end_boundary	(const GtkTextIter *iter,
+									 GtkTextIter       *leading_end);
+
+GTK_SOURCE_INTERNAL
+void		_gtk_source_iter_get_trailing_spaces_start_boundary	(const GtkTextIter *iter,
+									 GtkTextIter       *trailing_start);
+
 /* Internal functions, in the header for unit tests. */
 
 GTK_SOURCE_INTERNAL
