@@ -14,9 +14,8 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this library; if not, see <http://www.gnu.org/licenses/>.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -124,8 +123,12 @@ _gtk_source_language_new_from_file (const gchar              *filename,
         }
 	else
 	{
-		g_warning("Unable to open '%s'", filename);
+		g_warning ("Unable to open '%s'", filename);
 
+		if (fd != -1)
+		{
+			close (fd);
+		}
     	}
 
 	if (lang != NULL)
