@@ -14,22 +14,24 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this library; if not, see <http://www.gnu.org/licenses/>.
  */
 
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
 
+#include "gtksourcelanguagemanager.h"
+
 #include <string.h>
-#include "gtksourceview-i18n.h"
-#include "gtksourcelanguage-private.h"
-#include "gtksourcelanguage.h"
-#include "gtksourceview-utils.h"
 #include <gio/gio.h>
 
+#include "gtksourcelanguage.h"
+#include "gtksourcelanguage-private.h"
+#include "gtksourceview-utils.h"
+#include "gtksourceview-i18n.h"
+
 /**
  * SECTION:languagemanager
  * @Short_description: Provides access to GtkSourceLanguages
@@ -65,6 +67,8 @@ struct _GtkSourceLanguageManagerPrivate
 	gchar          **ids; /* Cache the IDs of the available languages */
 };
 
+static GtkSourceLanguageManager *default_instance;
+
 G_DEFINE_TYPE_WITH_PRIVATE (GtkSourceLanguageManager, gtk_source_language_manager, G_TYPE_OBJECT)
 
 static void
@@ -200,16 +204,20 @@ gtk_source_language_manager_new (void)
 GtkSourceLanguageManager *
 gtk_source_language_manager_get_default (void)
 {
-	static GtkSourceLanguageManager *instance;
-
-	if (instance == NULL)
+	if (default_instance == NULL)
 	{
-		instance = gtk_source_language_manager_new ();
-		g_object_add_weak_pointer (G_OBJECT (instance),
-					   (gpointer) &instance);
+		default_instance = gtk_source_language_manager_new ();
+		g_object_add_weak_pointer (G_OBJECT (default_instance),
+					   (gpointer) &default_instance);
 	}
 
-	return instance;
+	return default_instance;
+}
+
+GtkSourceLanguageManager *
+_gtk_source_language_manager_peek_default (void)
+{
+	return default_instance;
 }
 
 static void
