@@ -14,9 +14,8 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this library; if not, see <http://www.gnu.org/licenses/>.
  */
 
 #ifndef GTK_SOURCE_TYPES_PRIVATE_H
@@ -27,6 +26,7 @@
 G_BEGIN_DECLS
 
 typedef struct _GtkSourceBufferInputStream	GtkSourceBufferInputStream;
+typedef struct _GtkSourceBufferInternal		GtkSourceBufferInternal;
 typedef struct _GtkSourceBufferOutputStream	GtkSourceBufferOutputStream;
 typedef struct _GtkSourceCompletionContainer	GtkSourceCompletionContainer;
 typedef struct _GtkSourceCompletionModel	GtkSourceCompletionModel;
