@@ -22,6 +22,10 @@
  * along with this library; if not, see <http://www.gnu.org/licenses/>.
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "gtksourceundomanagerdefault.h"
 #include <string.h>
 #include "gtksourceundomanager.h"
